# About

The style sheet (cheatsheet.style) was originally developed Roberto Alsina.

https://github.com/ralsina/rst-cheatsheet

# Install

``` bash
pip install rst2pdf
```

# Build

``` bash
rst2pdf -s cheatsheet.style ../source/basics/cheatsheet.rst -o cheatsheet.pdf
```
